**Building manual.**

***How to build documentation?***
run ```bash build_docs.sh``` to generate markdown documentation for preview

***How to lint? Ruff !***
be sure you have installed pre-commit: ```pip install pre-commit```
now you can run ```pre-commit run``` to run pre-commit checks on changes
or ```pre-commit run --all-files``` to apply checks to all files